@@ -1,5 +1,7 @@
 #include "flashlightactiondialog.h"
 #include "ui_flashlightactiondialog.h"
+#include <QDesktopServices>
+#include <QUrl>
 
 FlashlightActionDialog::FlashlightActionDialog(QWidget *parent) :
         QDialog(parent),
@@ -12,6 +14,8 @@ FlashlightActionDialog::FlashlightActionDialog(QWidget *parent) :
     this->connect(this->ui->btnExitDaemon, SIGNAL(pressed()), this, SLOT(buttonQuitPressedSlot()));
     this->connect(this->ui->btnCamera, SIGNAL(pressed()), this, SLOT(buttonLaunchCameraPressedSlot()));
     this->connect(this->ui->btnFlashlight, SIGNAL(pressed()), this, SLOT(buttonLaunchFlashlightPressedSlot()));
+
+    this->connect(this->ui->btnHelp, SIGNAL(pressed()), this, SLOT(buttonHelpPressedSlot()));
 }
 
 FlashlightActionDialog::~FlashlightActionDialog()
@@ -31,3 +35,8 @@ void FlashlightActionDialog::buttonLaunchCameraPressedSlot(){
 void FlashlightActionDialog::buttonLaunchFlashlightPressedSlot(){
     emit this->buttonLaunchFlashlightPressedSignal();
 }
+
+void FlashlightActionDialog::buttonHelpPressedSlot(){
+     QDesktopServices::openUrl(QUrl("http://thecodecentral.com/flashlight-extra-for-maemo-nokia-n900", QUrl::TolerantMode));
+     this->hide();
+}
